import { InjectType } from '../@types/Injector';
import { Configuration } from '../Configuration';
/**
 * @abstract
 * @class
 * @classdesc The injector class. This class can't be instantiated.
 * @memberof module:Injector
 */
export default abstract class Injector {
    private static instances;
    /**
     * @private
     * @hideconstructor
     */
    private constructor();
    /**
     * This function is used to setup the configuration of the server
     *
     * @param {Configuration} config The configuration of the server
     */
    static setup(config: Configuration): void;
    /**
     * This function is used to get an injected object/variable.
     * If you have a class, you can use the [\@Retrive]{@link module:Injector.Retrive}
     * decorator
     * @param {string} name The name of the object/variable.
     * @return {T | null}
     * @example <caption>Example usage of [Injector.get]{@link module:Injector.Injector.get}.</caption>
     * [Injector.get]{@link module:Injector.Injector.get}<string>('name');
     * [Injector.get]{@link module:Injector.Injector.get}<Configuration>('Configuration');
     */
    static get<T>(name: string): T | null;
    /**
     * This function is used to inject an object/variable.
     * @param {string} name The name of the object/variable.
     * @param {any} value The object/variable.
     * @param {module:Injector.InjectType} type The type of the object
     * @return {void}
     */
    static inject(name: string, value: any, type?: InjectType): void;
    /**
     * This function will trigger the onLoad as a promise and
     * after will trigger the onReady
     */
    static ready(): Promise<void>;
}
//# sourceMappingURL=Injector.d.ts.map