"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var Injector_1 = __importDefault(require("./Injector"));
/**
 * This decorator is used to retrive/get an injected object/variable.
 * The Retrive decorator only works on the classes that have [\@Inject]{@link module:Injector.Inject}
 * or [\@Action]{@link module:Router.Action}
 * For fuctions/classes that can't use [\@Retrive]{@link module:Injector.Retrive},
 * use [Injector.get()]{@link module:Injector~Injector.get}
 * @static
 * @function Retrive
 * @memberof module:Injector
 * @return {any}
 * @param {string} name The name of the object/variable.
 * @example <caption>Example usage of [\@Retrive]{@link module:Injector.Retrive}.</caption>
 * export default class ClassName {
 *    [\@Retrive]{@link module:Injector.Retrive}('name')
 *    private variable?: Type;
 * }
 */
exports.default = (function (name) { return function (target, key) {
    var getter = function () {
        return Injector_1.default.get(name);
    };
    Object.defineProperty(target, key, {
        get: getter,
        configurable: false,
        enumerable: false
    });
}; });
//# sourceMappingURL=Retrive.js.map