declare const _default: (path: string, middlewares?: (string | Function)[] | undefined) => any;
/**
 * This decorator is used to define an action.
 * Actions are **automatically** injected.
 *
 * All the actions must be in ``src/actions`` and to have the ``@Action`` decorator.
 *
 * The middlewares can be [Class Middlewares (Injected)]{@link module:Injector~Middleware}
 * as strings or function middlewares.
 * @static
 * @return {any}
 * @method Action
 * @memberof module:Router
 * @param {!string} path The path of the router
 * @param {?Array.<string | Function>} middlewares Middlewares
 * @example <caption>Example usage of [\@Action]{@link module:Router.Action}.</caption>
 * [\@Action]{@link module:Router.Action}('/path', ['ClassMiddleware', functionMiddleware])
 * export default class ActionName {
 *
 * }
 */
export default _default;
//# sourceMappingURL=Action.d.ts.map