"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var ExpressTS_1 = __importDefault(require("../app/ExpressTS"));
/**
 * This decorator is used to define a Responder.
 * Responders are **automatically** injected.
 *
 * All the responders must be in ``src/responders`` and they must have [\@Inject]{@link module:Injector.Inject}
 *
 * For an example on how the responder is used, check the [example from \@Post]{@link module:Router.Post}.
 * @static
 * @return {any}
 * @method Responder
 * @memberof module:Router
 * @param {!string} name The name of the responder (This will have as prefix ``Responder.``)
 * @example <caption>Example usage of [\@Responder]{@link module:Router.Responder}.</caption>
 * [\@Inject]{@link module:Injector.Inject}
 * [\@Responder]{@link module:Router.Responder}('Name') // This will be accessed as 'Responder.Name'
 * export default class ResponderName {
 *    public success(res: Response) {
 *      return res.status(200).json({
 *        success: true
 *      });
 *    }
 *
 *    public created(res: Response, userId: string) {
 *      return res.status(201).json({
 *        success: true,
 *        userId
 *      });
 *    }
 * }
 */
exports.default = (function (name) { return function (constructor) {
    if (constructor.name === '_injected') {
        throw new Error('The responder must be called first!');
    }
    if (!ExpressTS_1.default.getData(constructor.name, 'responders')) {
        ExpressTS_1.default.setData(constructor.name, name, 'responders');
    }
    return constructor;
}; });
//# sourceMappingURL=Responder.js.map